@@ -43,13 +43,13 @@ x1t_common_config = dict(
 )
 
 xnt_common_config = dict(
-    n_tpc_pmts=493,
+    n_tpc_pmts=494,
     gain_model=('to_pe_constant',
                 0.005),
     channel_map=frozendict(
          # (Minimum channel, maximum channel)
          tpc=(0, 493),
-         lowgain=(500, 752),
+         he=(500, 752),  # high energy
          aqmon=(799, 807),
          tpc_blank=(999, 999),
          mv=(1000, 1083),
@@ -62,18 +62,10 @@ xnt_common_config = dict(
 # XENONnT
 ##
 
-
 def xenonnt_online(output_folder='./strax_data',
                    we_are_the_daq=False,
                    **kwargs):
     """XENONnT online processing and analysis"""
-    if we_are_the_daq:
-        run_db_username = straxen.get_secret('mongo_rdb_username')
-        run_db_password = straxen.get_secret('mongo_rdb_password')
-        mongo_url = f"mongodb://{run_db_username}:{run_db_password}@xenon1t-daq:27017,old-gw:27017/admin"
-    else:
-        mongo_url = None   # Default URL should work
-
     context_options = {
         **straxen.contexts.common_opts,
         **kwargs}
@@ -81,14 +73,15 @@ def xenonnt_online(output_folder='./strax_data',
     st = strax.Context(
         storage=[
             straxen.RunDB(
-                mongo_url=mongo_url,
-                runid_field='number',
                 readonly=not we_are_the_daq,
+                runid_field='number',
                 new_data_path=output_folder),
             strax.DataDirectory(
                 '/dali/lgrandi/xenonnt/raw',
                 readonly=True,
-                take_only='raw_records')],
+                take_only='raw_records'),
+            strax.DataDirectory(output_folder),
+        ],
         config=straxen.contexts.xnt_common_config,
         **context_options)
     st.register(straxen.DAQReader)
