@@ -67,12 +67,13 @@ class RunDB(strax.StorageFrontend):
         self.reader_ini_name_is_mode = reader_ini_name_is_mode
         if self.new_data_path is None:
             self.readonly = True
-
         self.runid_field = runid_field
 
         if self.runid_field not in ['name', 'number']:
             raise ValueError("Unrecognized runid_field option %s" % self.runid_field)
 
+        self.hostname = socket.getfqdn()
+
         if s3_kwargs is None:
             s3_kwargs = dict(
                 aws_access_key_id=straxen.get_secret('s3_access_key_id'),
@@ -84,7 +85,16 @@ class RunDB(strax.StorageFrontend):
                     retries=dict(max_attempts=10)))
 
         if mongo_url is None:
-            mongo_url = default_mongo_url
+            if self.hostname.endswith('xenon.local'):
+                username = straxen.get_secret('mongo_rdb_username')
+                password = straxen.get_secret('mongo_rdb_password')
+                url_base = 'xenon1t-daq:27017,old-gw:27017/admin'
+            else:
+                username = straxen.get_secret('rundb_username')
+                password = straxen.get_secret('rundb_password')
+                url_base = default_mongo_url
+            mongo_url = f"mongodb://{username}:{password}@{url_base}"
+
         self.client = pymongo.MongoClient(mongo_url.format(
             username=straxen.get_secret('rundb_username'),
             password=straxen.get_secret('rundb_password')))
@@ -102,7 +112,6 @@ class RunDB(strax.StorageFrontend):
 
         # Construct mongo query for runs with available data.
         # This depends on the machine you're running on.
-        self.hostname = socket.getfqdn()
         self.available_query = [{'host': self.hostname}]
         if not self.local_only:
             self.available_query.append({'host': 'ceph-s3'})
